@@ -1,10 +1,8 @@
 context("load taxa")
 
-test_that("We can load taxa from online", {
+test_that("We can load taxa", {
 
   needs_api()
-  df <- load_taxa(server = NULL)
-  expect_is(df, "tbl")
   df <- load_taxa(server = "fishbase")
   expect_is(df, "tbl")
   
